==> kylin-scanner_3.2.0.6.tar.gz: kylin-scanner-3.2.0.6/src/scansettingswidget.h <==
/*
* Copyright (C) 2021, KylinSoft Co., Ltd.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3, or (at your option)
* any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
*
*/
#ifndef SCANSETTINGSWIDGET_H
#define SCANSETTINGSWIDGET_H

#include "include/common.h"
#include "saneobject.h"
#include "globalsignal.h"
#include "sendmail.h"
#include "savefile.h"

#include <QWidget>
#include <QPaintEvent>
#include <QPainter>
#include <QPainterPath>
#include <QStyleOption>
#include <QColor>
#include <QFormLayout>
#include <QLabel>
#include <QPushButton>
#include <QLineEdit>
#include <QComboBox>
#include <QToolButton>
#include <QSpacerItem>
#include <QSize>
#include <QFontMetrics>
#include <QDir>
#include <QStandardPaths>
#include <QFile>
#include <QPdfWriter>
#include <QImage>
#include <QScrollArea>
#include <QScrollBar>
#include <QSizePolicy>


class ScanSettingsWidget : public QWidget
{
    Q_OBJECT

public:
    explicit ScanSettingsWidget(QWidget *parent = nullptr);

    void setupGui();
    void initConnect();

    void showTimeRow();
    void hideTimeRow();

    /// update scan settings throught sane api
    void updateScanButtonSettings();
    void updateDeviceSettings();
    void updatePageNumberSettings();
    void updateTimeSettings();
    void updateTypeSettings();
    void updateColorSettings();
    void updateResolutionSettings(bool DetectedDevices);
    void updateSizeSettings();
    void updateFormatSettings();
    void updateSaveNameTextSettings();
    void updateSaveNameTextWhileStopOrFinishedScan();
    void updateSaveDirectorySettings();
    void updateSendMailSettings();
    void updateSaveAsSettings();
    void updateSaveAsTextStore();
    void updateSaveAsTextRecover();
    void updateSettingsForDetectDevices();
    void updateSettingsForSwitchDevices();
    void updateSettingsStatusForStartScan();
    void updateSettingsStatusForEndScan(int saneStatus);

    int U(const char *str);
    int toUnicode(QString str);
    void setPdfSize(QPdfWriter *pdfWriter, QString size);
    void saveToPdf(QImage img, QString pathname);


    void setLabelAttributes(QLabel *label, const QString &text, int labelHeight = ScanSettingsLabelElideWidth);
    void setSaveButtonAttributes(QPushButton *button, const QString &text, int elideWidth);
    void setSaveButtonLabelAttributes(QLabel *label, const QString &text, int elideWidth);
    void setComboboxAttributes(QComboBox *combobox, QStringList strList);
    void setNameEditTooltip();
    void warnMsg(QString msg);


protected:
    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;


Q_SIGNALS:
    //void scanButtonClickedSignal();

public slots:
    void selectSaveDirectorySlot();

    void deviceCurrentTextChangedSlot(QString text);
    void pageNumberCurrentTextChangedSlot(QString text);
    void timeCurrentTextChangedSlot(QString text);
    void typeCurrentTextChangedSlot(QString text);
    void colorCurrentTextChangedSlot(QString text);
    void resolutionCurrentTextChangedSlot(QString text);
    void sizeCurrentTextChangedSlot(QString text);
    void formatCurrentTextChangedSlot(QString text);
    void nameCurrentTextChangedSlot(QString text);

    void sendMailButtonClickedSlot();
    void saveAsButtonClickedSlot();

    void scanButtonClickedSlot();

    void fontSizeChanged();
    void fontSizeChangedSlot();

private:
    QString currentSaveDirectory;
    QString currentSaveAsDirectory;

    QLabel *scanButtonLeftLabel;
    QLabel *scanButtonRightLabel;
    QHBoxLayout *scanButtonHLayout;
    QPushButton *m_scanButton;

    QLabel *m_deviceSettingsLabel;

    QLabel *m_deviceLabel;
    QComboBox *m_deviceComboBox;

    QLabel *m_pageNumberLabel;
    QComboBox *m_pageNumberComboBox;

    QLabel *m_timeLabel;
    QComboBox *m_timeComboBox;

    QLabel *m_typeLabel;
    QComboBox *m_typeComboBox;

    QLabel *m_colorLabel;
    QComboBox *m_colorComboBox;

    QLabel *m_resolutionLabel;
    QComboBox *m_resolutionComboBox;

    QLabel *m_fileSettingsLabel;

    QLabel *m_sizeLabel;
    QComboBox *m_sizeComboBox;

    QLabel *m_formatLabel;
    QComboBox *m_formatComboBox;

    QLabel *m_saveNameLabel;
    QLineEdit *m_saveNameEdit;

    QLabel *m_saveDirectoryLabel;
    QLabel *m_saveDirectoryButtonLabel;
    QHBoxLayout *m_saveDirectoryButtonLayout;
    QPushButton *m_saveDirectoryButton;

    QFormLayout *m_settingsFormLayout;

    QPushButton *m_sendMailButton;
    QPushButton *m_SaveAsButton;
    QHBoxLayout *m_buttonsHLayout;

    QScrollArea *m_mainScrollArea;

    QVBoxLayout *m_mainVLayout;

    bool isDarkTheme();
private slots:
    void initTheme();
};

#endif // SCANSETTINGSWIDGET_H

==> kylin-scanner_3.2.1.orig.tar.gz: kylin-scanner-3.2.1/src/scansettingswidget.h <==
/*
* Copyright (C) 2021, KylinSoft Co., Ltd.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 3, or (at your option)
* any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, see <http://www.gnu.org/licenses/&gt;.
*
*/
#ifndef SCANSETTINGSWIDGET_H
#define SCANSETTINGSWIDGET_H

#define UKUI_THEME_GSETTING_PATH "org.ukui.style"

#include "include/common.h"
#include "saneobject.h"
#include "globalsignal.h"
#include "sendmail.h"

#include <QWidget>
#include <QPaintEvent>
#include <QPainter>
#include <QPainterPath>
#include <QStyleOption>
#include <QColor>
#include <QFormLayout>
#include <QLabel>
#include <QPushButton>
#include <QLineEdit>
#include <QComboBox>
#include <QToolButton>
#include <QSpacerItem>
#include <QSize>
#include <QFontMetrics>
#include <QDir>
#include <QStandardPaths>
#include <QFile>
#include <QPdfWriter>
#include <QImage>
#include <QScrollArea>
#include <QScrollBar>
#include <QSizePolicy>
#include "runningdialog.h"


class ScanSettingsWidget : public QWidget
{
    Q_OBJECT

public:
    explicit ScanSettingsWidget(QWidget *parent = nullptr);

    void setupGui();
    void initConnect();

    void showTimeRow();
    void hideTimeRow();

    /// update scan settings throught sane api
    void updateScanButtonSettings();
    void updateDeviceSettings();
    void updatePageNumberSettings();
    void updateTimeSettings();
    void updateTypeSettings();
    void updateColorSettings();
    void updateResolutionSettings(bool DetectedDevices);
    void updateSizeSettings();
    void updateFormatSettings();
    void updateSaveNameTextSettings();
    void updateSaveDirectorySettings();
    void updateSendMailSettings();
    void updateSaveAsSettings();
    void updateSaveAsTextStore();
    void updateSaveAsTextRecover();

    void updateSettingsForSwitchDevices();
    void updateSettingsStatusForStartScan();
    void updateSettingsStatusForEndScan(int saneStatus);

    int U(const char *str);
    int toUnicode(QString str);
    void setPdfSize(QPdfWriter *pdfWriter, QString size);
    void saveToPdf(QImage img, QString pathname);


    void setLabelAttributes(QLabel *label, const QString &text, int labelHeight = ScanSettingsLabelElideWidth);
    void setSaveButtonAttributes(QPushButton *button, const QString &text, int elideWidth);
    void setSaveButtonLabelAttributes(QLabel *label, const QString &text, int elideWidth);
    void setComboboxAttributes(QComboBox *combobox, QStringList strList);
    void setNameEditTooltip();
    void warnMsg(QString msg);


protected:
    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;


Q_SIGNALS:
    //void scanButtonClickedSignal();

public slots:
    void rotateChangedSlot(bool isPCMode);
    void updateSettingsForDetectDevices();
    void selectSaveDirectorySlot();

    void deviceCurrentTextChangedSlot(QString text);
    void pageNumberCurrentTextChangedSlot(QString text);
    void timeCurrentTextChangedSlot(QString text);
    void typeCurrentTextChangedSlot(QString text);
    void colorCurrentTextChangedSlot(QString text);
    void resolutionCurrentTextChangedSlot(QString text);
    void sizeCurrentTextChangedSlot(QString text);
    void formatCurrentTextChangedSlot(QString text);
    void nameCurrentTextChangedSlot(QString text);

    void sendMailButtonClickedSlot();
    void saveAsButtonClickedSlot();

    void scanButtonClickedSlot();

    void fontSizeChanged();
    void fontSizeChangedSlot();
    void setDeviceBoxDisableSlot();
private:
    RunningDialog *m_runningDialog = nullptr;

    QString currentSaveDirectory;
    QString currentSaveAsDirectory;

    QLabel *scanButtonLeftLabel;
    QLabel *scanButtonRightLabel;
    QHBoxLayout *scanButtonHLayout;
    QPushButton *m_scanButton;
    QHBoxLayout *scanButtonCrapLayout;

    QLabel *m_deviceSettingsLabel;

    QLabel *m_deviceLabel;
    QComboBox *m_deviceComboBox;

    QLabel *m_pageNumberLabel;
    QComboBox *m_pageNumberComboBox;

    QLabel *m_timeLabel;
    QComboBox *m_timeComboBox;

    QLabel *m_typeLabel;
    QComboBox *m_typeComboBox;

    QLabel *m_colorLabel;
    QComboBox *m_colorComboBox;

    QLabel *m_resolutionLabel;
    QComboBox *m_resolutionComboBox;

    QLabel *m_fileSettingsLabel;

    QLabel *m_sizeLabel;
    QComboBox *m_sizeComboBox;

    QLabel *m_formatLabel;
    QComboBox *m_formatComboBox;

    QLabel *m_saveNameLabel;
    QLineEdit *m_saveNameEdit;

    QLabel *m_saveDirectoryLabel;
    QLabel *m_saveDirectoryButtonLabel;
    QHBoxLayout *m_saveDirectoryButtonLayout;
    QLineEdit *m_saveDirectoryButton;

    QFormLayout *m_settingsFormLayout;

    QPushButton *m_sendMailButton;
    QPushButton *m_SaveAsButton;
    QHBoxLayout *m_buttonsHLayout;

    QScrollArea *m_mainScrollArea;

    QVBoxLayout *m_mainVLayout;

    QGSettings *m_themeData = nullptr;
    bool isDarkTheme();
    bool showRunningDialog();
private slots:
    void initTheme();
    void setScanIconDisable();

};

#endif // SCANSETTINGSWIDGET_H
